SciPy
=====

:Release: |release|
:Date: |today|

SciPy (pronounced "Sigh Pie") is open-source software for mathematics,
science, and engineering.

.. toctree::
   :maxdepth: 1

   install_upgrade
   api
   release

Tutorial
--------

Tutorials with worked examples and background information for most SciPy
submodules.

.. toctree::
   :maxdepth: 2

   tutorial/index.rst

Developer's Guide
-----------------

Explanations of how to start contributing to SciPy, and descriptions of
maintenance activities and policies.

.. toctree::
   :maxdepth: 1

   dev/conduct/code_of_conduct
   hacking
   building/index
   dev/index
   dev/governance/governance

To get an overview of where help or new features are desired or planned, see
the roadmap:

.. toctree::
   :maxdepth: 1

   roadmap
   roadmap-detailed
   toolchain

.. module:: scipy

API Reference
-------------

The exact API of all functions and classes, as given by the docstrings. The API
documents expected types and allowed features for all functions, and all
parameters available for the algorithms.

.. toctree::
   :maxdepth: 1

   cluster
   constants
   fftpack
   integrate
   interpolate
   io
   linalg
   misc
   ndimage
   odr
   optimize
   signal
   sparse
   sparse.linalg
   sparse.csgraph
   spatial
   special
   stats
   stats.mstats
   ccallback
